MemoryAllocationModule

Struct MemoryAllocationModule 

#[repr(C)]
pub struct MemoryAllocationModule { pub header: Hob, pub alloc_descriptor: MemoryAllocation, pub module_name: Guid, pub entry_point: u64, }
Defines the location and entry point of the HOB consumer phase.

Fields

header: Hob

The HOB generic header. Header.HobType = EFI_HOB_TYPE_MEMORY_ALLOCATION.

alloc_descriptor: MemoryAllocation

An instance of the EFI_HOB_MEMORY_ALLOCATION_HEADER that describes the various attributes of the logical memory allocation.

module_name: Guid

The GUID specifying the values of the firmware file system name that contains the HOB consumer phase component.

entry_point: u64

The address of the memory-mapped firmware volume that contains the HOB consumer phase firmware file.