EfiTimerSetTimerPeriod

Type Alias EfiTimerSetTimerPeriod 

pub type EfiTimerSetTimerPeriod = extern "efiapi" fn(this: *mut Protocol, timer_period: u64) -> Status;
This function adjusts the period of timer interrupts to the value specified by TimerPeriod. If the timer period is updated, then the selected timer period is stored in EFI_TIMER.TimerPeriod, and EFI_SUCCESS is returned. If the timer hardware is not programmable, then EFI_UNSUPPORTED is returned. If an error occurs while attempting to update the timer period, then the timer hardware will be put back in its state prior to this call, and EFI_DEVICE_ERROR is returned. If TimerPeriod is 0, then the timer interrupt is disabled. This is not the same as disabling the CPU’s interrupts. Instead, it must either turn off the timer hardware, or it must adjust the interrupt controller so that a CPU interrupt is not generated when the timer interrupt fires.

  • this - The EFI_TIMER_ARCH_PROTOCOL instance.
  • timer_period - The rate to program the timer interrupt in 100 nS units. If the timer hardware is not programmable, then EFI_UNSUPPORTED is returned. If the timer is programmable, then the timer period will be rounded up to the nearest timer period that is supported by the timer hardware. If TimerPeriod is set to 0, then the timer interrupts will be disabled.
  • @retval - EFI_SUCCESS: The timer period was changed.
  • @retval - EFI_UNSUPPORTED: The platform cannot change the period of the timer interrupt.
  • @retval - EFI_DEVICE_ERROR: The timer period could not be changed due to a device error.