#[repr(C)]pub struct MemoryAllocation {
pub name: Guid,
pub memory_base_address: EfiPhysicalAddress,
pub memory_length: u64,
pub memory_type: MemoryType,
pub reserved: [u8; 4],
}Expand description
MemoryAllocation (EFI_HOB_MEMORY_ALLOCATION_HEADER) describes the various attributes of the logical memory allocation. The type field will be used for subsequent inclusion in the UEFI memory map.
Fields
name: GuidA GUID that defines the memory allocation region’s type and purpose, as well as other fields within the memory allocation HOB. This GUID is used to define the additional data within the HOB that may be present for the memory allocation HOB. Type EFI_GUID is defined in InstallProtocolInterface() in the UEFI 2.0 specification.
memory_base_address: EfiPhysicalAddressThe base address of memory allocated by this HOB. Type EfiPhysicalAddress is defined in AllocatePages() in the UEFI 2.0 specification.
memory_length: u64The length in bytes of memory allocated by this HOB.
memory_type: MemoryTypeDefines the type of memory allocated by this HOB. The memory type definition follows the EFI_MEMORY_TYPE definition. Type EFI_MEMORY_TYPE is defined in AllocatePages() in the UEFI 2.0 specification.
reserved: [u8; 4]This field will always be set to zero.